import React from 'react';
import { useWidgetContext } from '../../context';
import { StatisticsBarWrapper } from '../../shared/Statistic/presenters/StatisticsBarWrapper';
import { subtractDays, subtractMonths } from '../../dateUtils';
import { ChartType, createDaysArr, createMonthsArr, createYearsArr, getMonthsRate, getWeeksRate, getYearsRate, mapDaysRateForCharts, mapMonthsRateForCharts, mapYearsRateForCharts, parseResultForChart, useStatisticsData, } from '../../shared/Statistic/utils';
var NUMBER_OF_DAYS = 7;
var NUMBER_OF_MONTHS = 12;
var NUMBER_OF_YEARS = 4;
export var StatisticsBarController = function (_a) {
    var _b;
    var setView = _a.setView;
    var _c = useWidgetContext(), client = _c.client, title = _c.config.title;
    var dateNow = Date.now();
    var dateNowDateFormat = new Date(dateNow);
    var monthNumber = NUMBER_OF_MONTHS * NUMBER_OF_YEARS - (dateNowDateFormat.getUTCMonth() + 1);
    var requestParamsForWeek = {
        from: subtractDays(dateNow, NUMBER_OF_DAYS),
        limit: NUMBER_OF_DAYS,
    };
    var requestParamsForMonths = {
        from: subtractMonths(dateNow, monthNumber),
        limit: monthNumber,
    };
    var weekRateRareData = useStatisticsData(client, 'AutomationRate.Daily', requestParamsForWeek)[0];
    var monthsRateRareData = useStatisticsData(client, 'AutomationRate.Monthly', requestParamsForMonths)[0];
    var daysArr = createDaysArr(NUMBER_OF_DAYS, dateNow);
    var monthsArr = createMonthsArr(NUMBER_OF_MONTHS, dateNow);
    var yearsArr = createYearsArr(NUMBER_OF_YEARS, dateNow);
    var weekRate = getWeeksRate(weekRateRareData, daysArr);
    var monthsRate = getMonthsRate(monthsRateRareData, monthsArr);
    var yearsRate = getYearsRate(monthsRateRareData, yearsArr);
    var weekRateData = parseResultForChart(weekRate, mapDaysRateForCharts);
    var monthsRateData = parseResultForChart(monthsRate, mapMonthsRateForCharts);
    var yearsRateData = parseResultForChart(yearsRate, mapYearsRateForCharts);
    var rateData = (_b = {},
        _b[ChartType.weekly] = weekRateData,
        _b[ChartType.monthly] = monthsRateData,
        _b[ChartType.annual] = yearsRateData,
        _b);
    return (React.createElement(StatisticsBarWrapper, { title: title, setView: setView, rateData: rateData }));
};
